"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HabitRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
const handleError_1 = require("../utils/handleError");
class HabitRecord {
    constructor(obj) {
        this.id = obj.id;
        this.userId = obj.userId;
        this.name = obj.name;
        this.stats = obj.stats;
        this.color = obj.color;
        this.orderNo = obj.orderNo;
        this.firstStatDate = obj.firstStatDate;
        this.lastStatUpdateDate = obj.lastStatUpdateDate;
        this.validate();
    }
    validate() {
        if (!this.name) {
            throw new handleError_1.CustomError('Habit name is required.');
        }
        if (this.name.length > 40) {
            throw new handleError_1.CustomError('Habit name cannot be longer than 40 characters.');
        }
        if (this.color.length !== 7 || !this.color.includes('#')) {
            throw new handleError_1.CustomError('Habit color must be appropriate to hexadecimal pattern.');
        }
        if (!this.userId) {
            throw new handleError_1.CustomError('There is no userId', 500);
        }
    }
    static listAllByUserId(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT * FROM `habits` WHERE `userId` = :userId ORDER BY `orderNo`', { userId });
            return res.map(habit => new HabitRecord(Object.assign(Object.assign({}, habit), { stats: JSON.parse(habit.stats.toString()) })));
        });
    }
    static getOneById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT * FROM `habits` WHERE `id` = :id', { id });
            return res[0] ? new HabitRecord(Object.assign(Object.assign({}, res[0]), { stats: JSON.parse(res[0].stats.toString()) })) : null;
        });
    }
    static getHabitsCount(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT COUNT (*) AS "counter" FROM `habits` WHERE `userId` = :userId', { userId });
            return res[0].counter;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT * FROM `habits` WHERE `userId` = :userId AND `name` = :name', this);
            if (res[0]) {
                throw new handleError_1.CustomError('You have already added habit with that name.', 409);
            }
            this.id = (0, uuid_1.v4)();
            this.stats = Array(40).fill(0);
            yield db_1.pool.execute('INSERT INTO `habits` VALUES(:id, :userId, :name, :stats, :color, :orderNo, :firstStatDate, :lastStatUpdateDate)', Object.assign(Object.assign({}, this), { stats: JSON.stringify(this.stats) }));
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            this.validate();
            yield db_1.pool.execute('UPDATE `habits` SET `name` = :name, `stats` = :stats, `color` = :color, `orderNo` = :orderNo, `lastStatUpdateDate` = :lastStatUpdateDate WHERE `id` = :id', Object.assign(Object.assign({}, this), { stats: JSON.stringify(this.stats) }));
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `habits` WHERE `id` = :id', { id: this.id });
        });
    }
}
exports.HabitRecord = HabitRecord;
//# sourceMappingURL=habit-record.js.map