"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const user_record_1 = require("../records/user-record");
const db_1 = require("../utils/db");
const types_1 = require("../types");
const initialData = {
    email: 'test@test.test',
    password: 'Testowe123?',
    accountStatus: types_1.AccountStatus.ACTIVE
};
let user;
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
beforeAll(() => {
    user = new user_record_1.UserRecord(initialData);
});
test('Creating user with not valid email throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { email: 'test.test' }))).toThrow();
});
test('Creating user with no email throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { email: undefined }))).toThrow();
});
test('Creating user with password shorter than 8 characters throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'Test1?' }))).toThrow();
});
test('Creating user with password longer than 100 characters throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'Test1?fdfdshfjdshjkfdskjhfdhjkfkdsjhfdhjksfhjkdsfhjkdshjkfdkjshfhkjdsfkhjdfhdshjkfdshjkfhjdshfjkreiggffoiufdiugfdiuogudfio' }))).toThrow();
});
test('Creating user with password with no any special character from "?", "!", "@", "#", "$" or "%" throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12' }))).toThrow();
});
test('Creating user with password with any other special character than "?", "!", "@", "#", "$" or "%" throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12;' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12"' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12^' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12)' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12(' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12]' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12[' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12{' }))).toThrow();
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: 'TestTest12}' }))).toThrow();
});
test('Creating user with no password throws an error', () => {
    expect(() => new user_record_1.UserRecord(Object.assign(Object.assign({}, initialData), { password: undefined }))).toThrow();
});
test('Not inserted user should not have an id', () => {
    expect(user.id).toBeUndefined();
});
test('Inserted user should have an id as a valid v4 uuid.', () => __awaiter(void 0, void 0, void 0, function* () {
    yield user.insert();
    expect(user.id).toBeDefined();
    expect(user.id).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('Inserted user should have encrypted password', () => {
    expect(user.password === initialData.password).toBeFalsy();
});
test('Getting inserted user by email should returns user', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getByEmail(initialData.email);
    expect(user.id).toBeDefined();
    expect(user.email).toBeDefined();
    expect(user.password).toBeDefined();
    expect(user).toHaveProperty('refreshToken');
}));
test('Getting inserted user by id should returns user', () => __awaiter(void 0, void 0, void 0, function* () {
    const userById = yield user_record_1.UserRecord.getById(user.id);
    expect(userById.id).toBeDefined();
    expect(userById.email).toBeDefined();
    expect(userById.password).toBeDefined();
    expect(userById).toHaveProperty('refreshToken');
}));
test('Getting by id not existing user should return null', () => __awaiter(void 0, void 0, void 0, function* () {
    const userNull = yield user_record_1.UserRecord.getById('12121212121212121212121212121');
    expect(userNull).toBeNull();
}));
test('Getting by email not existing user should return null', () => __awaiter(void 0, void 0, void 0, function* () {
    const userNull = yield user_record_1.UserRecord.getByEmail('test.test.test@test.test');
    expect(userNull).toBeNull();
}));
test('Using delete method should delete user.', () => __awaiter(void 0, void 0, void 0, function* () {
    yield user.delete();
    const userAfterDelete = yield user_record_1.UserRecord.getByEmail(initialData.email);
    expect(userAfterDelete).toBeNull();
}));
//# sourceMappingURL=user.test.js.map